pub struct Errno(_);

Implementations

Operation not permitted

No such file or directory

No such process

Interrupted system call

I/O error

No such device or address

Argument list too long

Exec format error

Bad file number

No child processes

Try again

Out of memory

Permission denied

Bad address

Block device required

Device or resource busy

File exists

Cross-device link

No such device

Not a directory

Is a directory

Invalid argument

File table overflow

Too many open files

Not a typewriter

Text file busy

File too large

No space left on device

Illegal seek

Read-only file system

Too many links

Broken pipe

Math argument out of domain of func

Math result not representable

Resource deadlock would occur

File name too long

No record locks available

Invalid system call number

Directory not empty

Too many symbolic links encountered

No message of desired type

Identifier removed

Channel number out of range

Level 2 not synchronized

Level 3 halted

Level 3 reset

Link number out of range

Protocol driver not attached

No CSI structure available

Level 2 halted

Invalid exchange

Invalid request descriptor

Exchange full

No anode

Invalid request code

Invalid slot

Bad font file format

Device not a stream

No data available

Timer expired

Out of streams resources

Machine is not on the network

Package not installed

Object is remote

Link has been severed

Advertise error

Srmount error

Communication error on send

Protocol error

Multihop attempted

RFS specific error

Not a data message

Value too large for defined data type

Name not unique on network

File descriptor in bad state

Remote address changed

Can not access a needed shared library

Accessing a corrupted shared library

.lib section in a.out corrupted

Attempting to link in too many shared libraries

Cannot exec a shared library directly

Illegal byte sequence

Interrupted system call should be restarted

Streams pipe error

Too many users

Socket operation on non-socket

Destination address required

Message too long

Protocol wrong type for socket

Protocol not available

Protocol not supported

Socket type not supported

Operation not supported on transport endpoint

Protocol family not supported

Address family not supported by protocol

Address already in use

Cannot assign requested address

Network is down

Network is unreachable

Network dropped connection because of reset

Software caused connection abort

Connection reset by peer

No buffer space available

Transport endpoint is already connected

Transport endpoint is not connected

Cannot send after transport endpoint shutdown

Too many references: cannot splice

Connection timed out

Connection refused

Host is down

No route to host

Operation already in progress

Operation now in progress

Stale file handle

Structure needs cleaning

Not a XENIX named type file

No XENIX semaphores available

Is a named type file

Remote I/O error

Quota exceeded

No medium found

Wrong medium type

Operation Canceled

Required key not available

Key has expired

Key has been revoked

Key was rejected by service

Owner died

State not recoverable

Operation not possible due to RF-kill

Memory page has hardware error

Restart syscall

Restart if no interrupt

restart if no handler..

No ioctl command

restart by calling sys_restart_syscall

Driver requests probe retry

open found a stale dentry

Parameter not supported

Illegal NFS file handle

Update synchronization mismatch

Cookie is stale

Operation is not supported

Buffer or request is too small

An untranslatable error occurred

Type not supported by server

Request initiated, but will not complete before timeout

iocb queued, will get completion event

conflict with recalled state

NFS file lock reclaim refused

Returns a pair containing the name of the error and a string describing the error.

Operation would block. This is the same as Errno::EAGAIN.

Same as Errno::EDEADLK.

Creates a new Errno.

Converts the Errno into a raw i32.

Returns true if the error code is valid (i.e., less than 4096).

Converts a raw syscall return value to a result.

Returns the last error that occurred.

Converts a value into an Errno.

Returns the name of the error. If the internal error code is unknown or invalid, None is returned.

Returns the error description. If the internal error code is unknown or invalid, None is returned.

Converts an std::io::Error into an Errno if possible. Since an error code is just one of the few possible error types that std::io::Error can represent, this will return None if the conversion is not possible.

A From<std::io::Error> implementation is not provided because this conversion can fail. However, the reverse is possible, so that is provided as a From implementation.